@@ -10,9 +10,11 @@ logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
 
-class ProperlyEvents(Enum):
+class ProperlyEvents(str, Enum):
     USER_CREATED = 'userCreated'
-    COMPLETED_OFFER = 'completedOffer'
+    STAGE_CHANGED_OFFER = 'stageChangedOffer'
+    USER_ENTERED_ALL_OFFER_INFO = 'userEnteredAllOfferInfo'
+    SHOWING_UPDATED_OR_CREATED = 'userShowingUpdatedOrCreated'
 
 
 STREAM_BY_STAGE = {
@@ -21,7 +23,13 @@ STREAM_BY_STAGE = {
 }
 
 
-class EventBus:
+class EventBusBase:
+
+    def send_event(self, properly_user_id: str, event_name: ProperlyEvents, data_block_name: str, data_block: dict):
+        raise NotImplementedError
+
+
+class EventBus(EventBusBase):
 
     def __init__(self, kinesis=None):
         stage = os.environ.get('PROPERLY_STAGE', 'staging')
